@@ -4,8 +4,9 @@
 # Copyright (C) 2015 Antonino Ingargiola <tritemio@gmail.com>
 #
 
-from . import loader
-from . import hdf5
+import phconvert.loader
+import phconvert.hdf5
+import phconvert.v04
 
 has_matplotlib = True
 try:
@@ -13,8 +14,9 @@ try:
 except ImportError:
     has_matplotlib = False
 if has_matplotlib:
-    from . import plotter
+    import phconvert.plotter
+    del matplotlib
 
-from ._version import get_versions
+from phconvert._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
