@@ -1083,7 +1083,7 @@ def _assert_valid_fields(h5file, strict_description=True, verbose=False):
             # Check fields use official description
             msg = 'Description (TITLE) for "%s" not compliant.' % metaname
             _assert_valid(title.decode() == official_fields_specs[metaname][0],
-                          msg)
+                          msg, strict=strict_description)
 
             # Check fields have correct type
             official_type = official_fields_specs[metaname][1]
@@ -1102,6 +1102,13 @@ def _assert_valid_fields(h5file, strict_description=True, verbose=False):
             elif official_type == 'array':
                 msg = '"%s" must be an array.' % pathname
                 _assert_valid(node.ndim >= 1, msg)
+                # check that photon_data arrays are strictly 1D
+                ph_data_arrays = ('timestamps', 'detectors', 'nanotimes',
+                                  'particles')
+                if node._v_name in ph_data_arrays:
+                    msg = ('The array /photon_data/%s must be 1D. '
+                           'It is %dD instead.' % (node._v_name, node.ndim))
+                    _assert_valid(node.ndim == 1, msg)
             else:
                 raise ValueError('Wrong type in JSON specs.')
 
@@ -1147,6 +1154,10 @@ def _check_photon_data_tables(ph_data, setup, norepeat=False, pool=None,
         _msg = ('%s measurement requires /setup/num_spectral_ch = 2 '
                 '(not %d).' % (meas_type, num_ch['spectral']))
         _assert_valid(num_ch['spectral'] == 2, msg=_msg)
+        for branch in ('split', 'polarization'):
+            _msg = ('%s measurement requires /setup/num_%s_ch = 1 '
+                    '(not %d).' % (meas_type, branch, num_ch[branch]))
+            _assert_valid(num_ch[branch] == 1, msg=_msg)
     if meas_type == 'smFRET-usALEX-3c':
         _msg = ('%s measurement requires /setup/num_spectral_ch = 3 '
                 '(not %d).' % (meas_type, num_ch['spectral']))
@@ -1172,6 +1183,13 @@ def _check_photon_data_tables(ph_data, setup, norepeat=False, pool=None,
              "is missing.")
         _assert_has_field('laser_repetition_rate', meas_specs,
                           msg_add=msg0 + m)
+    else:
+        # All lasers are CW, check that there is no pulsed laser field
+        msg = ('According to /setup/excitation_cw all lasera are CW.\n'
+               'However, `%s` has the field `laser_repetition_rate`.')
+        _assert_valid('laser_repetition_rate' not in setup, msg % 'setup')
+        _assert_valid('laser_repetition_rate' not in meas_specs,
+                      msg % 'measurement_specs')
 
     msg_cw = """
     According to /setup/excitation_alternated this measurement uses
@@ -1182,6 +1200,15 @@ def _check_photon_data_tables(ph_data, setup, norepeat=False, pool=None,
         if any(setup.excitation_alternated[:]):
             _assert_has_field('alex_period', meas_specs,
                               msg_add=dedent(msg_cw))
+        else:
+            # No alternated laser, check that no ALEX field is present
+            msg0 = ('According to /setup/excitation_alternated '
+                    'no laser is alternated.\n')
+            msg1 = 'However, measurement_specs has the ALEX field `%s`.'
+            fields = ['alex_period', 'alex_offset']
+            fields += ['alex_excitation_period%d' % i for i in (1, 2, 3)]
+            for field in fields:
+                _assert_valid(field not in meas_specs, msg0 + msg1 % field)
 
     if 'nanotimes' in ph_data and 'lifetime' in setup:
         _assert_valid(setup.lifetime.read(),
